[![Documentation Status](https://readthedocs.org/projects/pip/badge/?version=stable)](https://pip.pypa.io/en/stable/?badge=stable)
[![codecov](https://codecov.io/gh/Whist-Team/Whist-Core/branch/main/graph/badge.svg)](https://codecov.io/gh/Whist-Team/Whist-Core)
![PyPI](https://img.shields.io/pypi/v/whist-core)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/whist-core)
![GitHub repo size](https://img.shields.io/github/repo-size/whist-team/whist-core)
![Lines of code](https://img.shields.io/tokei/lines/github/whist-team/whist-core)
![PyPI - Downloads](https://img.shields.io/pypi/dm/whist-core)
![PyPI - License](https://img.shields.io/pypi/l/whist-core)


# Whist-Core
Rules implementation

## Run tests
```bash
# Create venv
python3 -m venv venv
source venv/bin/activate
pip install -U pip setuptools wheel

# Install with 'testing' extras
pip install -e .[testing]

# Run tests
python -m pytest
```